@@ -6,6 +6,7 @@ import os
 import sys
 import threading
 import traceback
+import logging
 
 import bugsnag
 from bugsnag.utils import sanitize_object, json_encode
@@ -27,8 +28,12 @@ def deliver(payload, url):
                 bugsnag.log("Notification to %s failed, status %d" % (url, status))
 
         except Exception:
-            bugsnag.log("Notification to %s failed" % (req.get_full_url()))
-            print((traceback.format_exc()))
+            try:
+                bugsnag.log("Notification to %s failed" % (req.get_full_url()))
+                print((traceback.format_exc()))
+            except Exception:
+                print(("[BUGSNAG] error in request thread exception handler."))
+                pass
 
     threading.Thread(target=request).start()
 
@@ -154,6 +159,7 @@ class Notification(object):
             trace = traceback.extract_stack()
 
         bugsnag_module_path = os.path.dirname(bugsnag.__file__)
+        logging_module_path = os.path.dirname(logging.__file__)
 
         lib_root = self.config.get("lib_root")
         if lib_root and lib_root[-1] != os.sep:
@@ -171,6 +177,9 @@ class Notification(object):
             if file_name.startswith(bugsnag_module_path):
                 continue
 
+            if file_name.startswith(logging_module_path):
+                continue
+
             if lib_root and file_name.startswith(lib_root):
                 file_name = file_name[len(lib_root):]
             elif project_root and file_name.startswith(project_root):
